@@ -172,7 +172,7 @@ static void inc_new_length(unsigned int length,
 		if (value == CHARSET_NEW) {
 			if ((value = getc(file)) != (int)length) break;
 			if ((value = getc(file)) == EOF) break;
-			if (value < 0 || value > length)
+			if (value < 0 || value > (int)length)
 				inc_format_error(charset);
 			pos = value;
 		} else
@@ -485,8 +485,17 @@ void do_incremental_crack(struct db_main *db, char *mode)
 	if (feof(file)) inc_format_error(charset);
 
 	allchars[header->count] = 0;
-	if (expand(allchars, extra ? extra : "", sizeof(allchars)))
+	if (expand(allchars, "", sizeof(allchars)))
 		inc_format_error(charset);
+	if (extra && expand(allchars, extra, sizeof(allchars))) {
+		log_event("! Extra characters not in compile-time "
+			"specified range ('\\x%02x' to '\\x%02x')",
+			CHARSET_MIN, CHARSET_MAX);
+		fprintf(stderr, "Extra characters not in compile-time "
+			"specified range ('\\x%02x' to '\\x%02x')\n",
+			CHARSET_MIN, CHARSET_MAX);
+		error();
+	}
 	real_count = strlen(allchars);
 
 	if (max_count < 0) max_count = CHARSET_SIZE;
