@@ -318,10 +318,11 @@ static void ldr_load_pw_line(struct db_main *db, char *line)
 
 		if ((current_pw = db->password_hash[pw_hash]))
 		do {
-			if (!strcmp(current_pw->source, piece)) {
-				if (!(db->options->flags & DB_WORDS)) break;
-
-				if (!strcmp(current_pw->login, login)) break;
+			if (!memcmp(current_pw->binary, binary,
+			    format->params.binary_size) &&
+			    !strcmp(current_pw->source, piece)) {
+				if (!(db->options->flags & DB_WORDS) ||
+				    !strcmp(current_pw->login, login)) break;
 			}
 		} while ((current_pw = current_pw->next_hash));
 
@@ -332,9 +333,9 @@ static void ldr_load_pw_line(struct db_main *db, char *line)
 
 		if ((current_salt = db->salt_hash[salt_hash]))
 		do {
-			if (!memcmp(
-				current_salt->salt, salt,
-				format->params.salt_size)) break;
+			if (!memcmp(current_salt->salt, salt,
+			    format->params.salt_size))
+				break;
 		} while ((current_salt = current_salt->next));
 
 		if (!current_salt) {
@@ -407,16 +408,22 @@ static void ldr_load_pot_line(struct db_main *db, char *line)
 {
 	struct fmt_main *format = db->format;
 	char *ciphertext;
+	void *binary;
 	int hash;
 	struct db_password *current;
 
 	ciphertext = ldr_get_field(&line);
-	if (!format->methods.valid(ciphertext)) return;
+	if (format->methods.valid(ciphertext) != 1) return;
+
+	ciphertext = format->methods.split(ciphertext, 0);
+	binary = format->methods.binary(ciphertext);
+	hash = LDR_HASH_FUNC(binary);
 
-	hash = LDR_HASH_FUNC(format->methods.binary(ciphertext));
 	if ((current = db->password_hash[hash]))
 	do {
-		if (!strcmp(current->source, ciphertext))
+		if (current->binary && !memcmp(current->binary, binary,
+		    format->params.binary_size) &&
+		    !strcmp(current->source, ciphertext))
 			current->binary = NULL;
 	} while ((current = current->next_hash));
 }
@@ -577,7 +584,7 @@ static int ldr_cracked_hash(char *ciphertext)
 
 	while (*ciphertext) {
 		hash <<= 1;
-		hash ^= *ciphertext++;
+		hash ^= *ciphertext++ | 0x20; /* ASCII case insensitive */
 	}
 
 	hash ^= hash >> CRACKED_HASH_LOG;
@@ -630,7 +637,7 @@ static void ldr_show_pw_line(struct db_main *db, char *line)
 	char source[LINE_BUFFER_SIZE];
 	struct fmt_main *format;
 	char *(*split)(char *ciphertext, int index);
-	int index, count;
+	int index, count, unify;
 	char *login, *ciphertext, *gecos, *home;
 	char *piece;
 	int pass, found, chars;
@@ -646,9 +653,11 @@ static void ldr_show_pw_line(struct db_main *db, char *line)
 
 	if (format) {
 		split = format->methods.split;
+		unify = format->params.flags & FMT_SPLIT_UNIFIES_CASE;
 	} else {
 		split = fmt_default_split;
 		count = 1;
+		unify = 0;
 	}
 
 	if (!*ciphertext) {
@@ -660,13 +669,28 @@ static void ldr_show_pw_line(struct db_main *db, char *line)
 	for (found = pass = 0; pass == 0 || (pass == 1 && found); pass++)
 	for (index = 0; index < count; index++) {
 		piece = split(ciphertext, index);
+		if (unify)
+			piece = strcpy(mem_alloc(strlen(piece) + 1), piece);
+
 		hash = ldr_cracked_hash(piece);
 
 		if ((current = db->cracked_hash[hash]))
 		do {
-			if (!strcmp(current->ciphertext, piece)) break;
+			if (!strcmp(current->ciphertext, piece))
+				break;
+/* This extra check, along with ldr_cracked_hash() being case-insensitive,
+ * is only needed for matching some pot file records produced by older
+ * versions of John and contributed patches where split() didn't unify the
+ * case of hex-encoded hashes. */
+			if (unify &&
+			    format->methods.valid(current->ciphertext) == 1 &&
+			    !strcmp(split(current->ciphertext, 0), piece))
+				break;
 		} while ((current = current->next));
 
+		if (unify)
+			MEM_FREE(piece);
+
 		if (pass) {
 			chars = 0;
 			if (show) {
