@@ -1,15 +1,18 @@
 /*
  * This file is part of John the Ripper password cracker,
- * Copyright (c) 1996-98 by Solar Designer
+ * Copyright (c) 1996-2001 by Solar Designer
  */
 
 /*
- * 64 bit integer math functions.
+ * 64-bit integer math functions.
  */
 
 #ifndef _JOHN_MATH_H
 #define _JOHN_MATH_H
 
+#undef int64
+#define int64 _john_int64_t
+
 typedef struct {
 	unsigned int lo, hi;
 } int64;
